@@ -55,6 +55,7 @@ from aexpect.exceptions import ExpectTimeoutError
 from aexpect.exceptions import ExpectProcessTerminatedError
 from aexpect import rss_client
 
+LOG = logging.getLogger(__name__)
 
 #: prompt to be used for shell sessions on linux machines (default)
 PROMPT_LINUX = r"^\[.*\][\#\$]\s*$"
@@ -75,7 +76,7 @@ class LoginError(RemoteError):
         self.output = output
 
     def __str__(self):
-        return "%s    (output: %r)" % (self.msg, self.output)
+        return f"{self.msg}    (output: {self.output!r})"
 
 
 class LoginAuthenticationError(LoginError):
@@ -97,8 +98,8 @@ class LoginProcessTerminatedError(LoginError):
         self.status = status
 
     def __str__(self):
-        return ("%s    (status: %s,    output: %r)" %
-                (self.msg, self.status, self.output))
+        return (f"{self.msg}    (status: {self.status},    "
+                f"output: {self.output!r})")
 
 
 class LoginBadClientError(LoginError):
@@ -109,7 +110,7 @@ class LoginBadClientError(LoginError):
         self.client = client
 
     def __str__(self):
-        return "%s    (value: %r)" % (self.msg, self.client)
+        return f"{self.msg}    (value: {self.client!r})"
 
 
 class TransferError(RemoteError):
@@ -121,7 +122,7 @@ class TransferError(RemoteError):
         self.output = output
 
     def __str__(self):
-        return "%s    (output: %r)" % (self.msg, self.output)
+        return f"{self.msg}    (output: {self.output!r})"
 
 
 class TransferBadClientError(RemoteError):
@@ -132,7 +133,8 @@ class TransferBadClientError(RemoteError):
         self.client = client
 
     def __str__(self):
-        return "Unknown file copy client: '%s', valid values are scp and rss" % self.client
+        return (f"Unknown file copy client: '{self.client}', "
+                "valid values are scp and rss")
 
 
 class SCPError(TransferError):
@@ -165,8 +167,8 @@ class SCPTransferFailedError(SCPError):
         self.status = status
 
     def __str__(self):
-        return ("SCP transfer failed    (status: %s,    output: %r)" %
-                (self.status, self.output))
+        return (f"SCP transfer failed    (status: {self.status},    "
+                f"output: {self.output!r})")
 
 
 class NetcatError(TransferError):
@@ -188,8 +190,8 @@ class NetcatTransferFailedError(NetcatError):
         self.status = status
 
     def __str__(self):
-        return ("Netcat transfer failed    (status: %s,    output: %r)" %
-                (self.status, self.output))
+        return (f"Netcat transfer failed    (status: {self.status},    "
+                f"output: {self.output!r})")
 
 
 class NetcatTransferIntegrityError(NetcatError):
@@ -265,13 +267,13 @@ def handle_prompts(session, username, password, prompt=PROMPT_LINUX,
             output += text
             if match == 0:  # "Are you sure you want to continue connecting"
                 if debug:
-                    logging.debug("Got 'Are you sure...', sending 'yes'")
+                    LOG.debug("Got 'Are you sure...', sending 'yes'")
                 session.sendline("yes")
             elif match in [1, 2, 3, 10]:  # "password:"
                 if password_prompt_count == 0:
                     if debug:
-                        logging.debug("Got password prompt, sending '%s'",
-                                      password)
+                        LOG.debug("Got password prompt, sending '%s'",
+                                  password)
                     session.sendline(password)
                     password_prompt_count += 1
                 else:
@@ -280,8 +282,8 @@ def handle_prompts(session, username, password, prompt=PROMPT_LINUX,
             elif match in [4, 9]:  # "login:"
                 if login_prompt_count == 0 and password_prompt_count == 0:
                     if debug:
-                        logging.debug("Got username prompt; sending '%s'",
-                                      username)
+                        LOG.debug("Got username prompt; sending '%s'",
+                                  username)
                     session.sendline(username)
                     login_prompt_count += 1
                 else:
@@ -290,36 +292,36 @@ def handle_prompts(session, username, password, prompt=PROMPT_LINUX,
                     else:
                         msg = "Got username prompt after password prompt"
                     raise LoginAuthenticationError(msg, text)
-            elif match == 5:   # "Connection closed"
+            elif match == 5:  # "Connection closed"
                 raise LoginError("Client said 'connection closed'", text)
-            elif match == 6:   # "Connection refused"
+            elif match == 6:  # "Connection refused"
                 raise LoginError("Client said 'connection refused'", text)
             elif match == 11:  # Connection timeout
                 raise LoginError("Client said 'connection timeout'", text)
             elif match == 15:  # Connection lost
                 raise LoginError("Disconnected to vm on remote host", text)
-            elif match == 7:   # "Please wait"
+            elif match == 7:  # "Please wait"
                 if debug:
-                    logging.debug("Got 'Please wait'")
+                    LOG.debug("Got 'Please wait'")
                 timeout = 30
-            elif match == 8:   # "Warning added RSA"
+            elif match == 8:  # "Warning added RSA"
                 if debug:
-                    logging.debug("Got 'Warning added RSA to known host list")
+                    LOG.debug("Got 'Warning added RSA to known host list")
             elif match == 12:  # prompt
                 if debug:
-                    logging.debug("Got shell prompt -- logged in")
+                    LOG.debug("Got shell prompt -- logged in")
                 break
             elif match == 13:  # console prompt
-                logging.debug("Got console prompt, send return to show login")
+                LOG.debug("Got console prompt, send return to show login")
                 session.sendline()
             elif match == 14:  # VMware vCenter command prompt
                 # Some old vsphere version (e.x. 6.0.0) needs to enable first.
                 cmd = 'shell.set --enabled True'
-                logging.debug(
+                LOG.debug(
                     "Got VMware VCenter prompt, "
                     "send '%s' to enable shell first", cmd)
                 session.sendline(cmd)
-                logging.debug(
+                LOG.debug(
                     "Got VMware VCenter prompt, "
                     "send 'shell' to launch bash")
                 session.sendline('shell')
@@ -344,7 +346,8 @@ def remote_login(client, host, port, username, password, prompt, linesep="\n",
                  interface=None, identity_file=None,
                  status_test_command="echo $?", verbose=False, bind_ip=None,
                  preferred_authenticaton='password',
-                 user_known_hosts_file='/dev/null'):
+                 user_known_hosts_file='/dev/null',
+                 extra_cmdline=''):
     """
     Log into a remote host (guest) using SSH/Telnet/Netcat.
 
@@ -372,38 +375,42 @@ def remote_login(client, host, port, username, password, prompt, linesep="\n",
                     client(specify interface ip)
     :param preferred_authenticaton: Given value of PreferredAuthentications in ssh
     :param user_known_hosts_file: Given value of UserKnownHostsFile in ssh
+    :param extra_cmdline: Additional params for the session, like -X for SSH.
     :raise LoginError: If using ipv6 linklocal but not assign a interface that
                        the neighbour attache
     :raise LoginBadClientError: If an unknown client is requested
     :raise: Whatever handle_prompts() raises
     :return: A RemoteSession object.
     """
-    verbose = "-vv" if verbose else ""
+    extra_params = []
+    if verbose:
+        extra_params.append("-vv")
+    if extra_cmdline:
+        extra_params.append(extra_cmdline)
     if host and host.lower().startswith("fe80"):
         if not interface:
             raise RemoteError("When using ipv6 linklocal an interface must "
                               "be assigned")
-        host = "%s%%%s" % (host, interface)
+        host = f"{host}%{interface}"
     if client == "ssh":
-        cmd = ("ssh %s -o UserKnownHostsFile=%s "
-               "-o StrictHostKeyChecking=no -p %s" %
-               (verbose, user_known_hosts_file, port))
+        cmd = (f"ssh {' '.join(extra_params)} -o UserKnownHostsFile={user_known_hosts_file} "
+               f"-o StrictHostKeyChecking=no -p {port}")
         if bind_ip:
-            cmd += (" -b %s" % bind_ip)
+            cmd += f" -b {bind_ip}"
         if identity_file:
-            cmd += (" -i %s" % identity_file)
+            cmd += f" -i {identity_file}"
         else:
-            cmd += " -o PreferredAuthentications=%s" % preferred_authenticaton
-        cmd += " %s@%s" % (username, host)
+            cmd += f" -o PreferredAuthentications={preferred_authenticaton}"
+        cmd += f" {username}@{host}"
     elif client == "telnet":
-        cmd = "telnet -l %s %s %s" % (username, host, port)
+        cmd = f"telnet -l {username} {host} {port}"
     elif client == "nc":
-        cmd = "nc %s %s %s" % (verbose, host, port)
+        cmd = f"nc {verbose} {host} {port}"
     else:
         raise LoginBadClientError(client)
 
     if verbose:
-        logging.debug("Login command: '%s'", cmd)
+        LOG.debug("Login command: '%s'", cmd)
     session = RemoteSession(cmd, linesep=linesep, prompt=prompt,
                             status_test_command=status_test_command,
                             client=client, host=host, port=port,
@@ -440,8 +447,8 @@ def wait_for_login(client, host, port, username, password, prompt,
     :raise: Whatever remote_login() raises
     :return: A RemoteSession object.
     """
-    logging.debug("Attempting to log into %s:%s using %s (timeout %ds)",
-                  host, port, client, timeout)
+    LOG.debug("Attempting to log into %s:%s using %s (timeout %ds)",
+              host, port, client, timeout)
     end_time = time.time() + timeout
     verbose = False
     while time.time() < end_time:
@@ -452,7 +459,7 @@ def wait_for_login(client, host, port, username, password, prompt,
                                 preferred_authenticaton=preferred_authenticaton,
                                 user_known_hosts_file=user_known_hosts_file)
         except LoginError as error:
-            logging.debug(error)
+            LOG.debug(error)
             verbose = True
         time.sleep(2)
     # Timeout expired; try one more time but don't catch exceptions
@@ -498,20 +505,20 @@ def _remote_scp(
                 [r"[Aa]re you sure", r"[Pp]assword:\s*$", r"lost connection"],
                 timeout=timeout, internal_timeout=0.5)
             if match == 0:  # "Are you sure you want to continue connecting"
-                logging.debug("Got 'Are you sure...', sending 'yes'")
+                LOG.debug("Got 'Are you sure...', sending 'yes'")
                 session.sendline("yes")
             elif match == 1:  # "password:"
                 if password_prompt_count == 0:
-                    logging.debug("Got password prompt, sending '%s'",
-                                  password_list[password_prompt_count])
+                    LOG.debug("Got password prompt, sending '%s'",
+                              password_list[password_prompt_count])
                     session.sendline(password_list[password_prompt_count])
                     password_prompt_count += 1
                     timeout = transfer_timeout
                     if scp_type == 1:
                         authentication_done = True
                 elif password_prompt_count == 1 and scp_type == 2:
-                    logging.debug("Got password prompt, sending '%s'",
-                                  password_list[password_prompt_count])
+                    LOG.debug("Got password prompt, sending '%s'",
+                              password_list[password_prompt_count])
                     session.sendline(password_list[password_prompt_count])
                     password_prompt_count += 1
                     timeout = transfer_timeout
@@ -527,7 +534,7 @@ def _remote_scp(
             raise SCPAuthenticationTimeoutError(error.output) from error
         except ExpectProcessTerminatedError as error:
             if error.status == 0:
-                logging.debug("SCP process terminated with status 0")
+                LOG.debug("SCP process terminated with status 0")
                 break
             raise SCPTransferFailedError(error.status, error.output) from error
 
@@ -549,8 +556,8 @@ def remote_scp(command, password_list, log_filename=None, log_function=None,
             or the password prompt)
     :raise: Whatever _remote_scp() raises
     """
-    logging.debug("Trying to SCP with command '%s', timeout %ss",
-                  command, transfer_timeout)
+    LOG.debug("Trying to SCP with command '%s', timeout %ss",
+              command, transfer_timeout)
     if log_filename:
         output_func = log_function
         output_params = (log_filename,)
@@ -584,23 +591,22 @@ def scp_to_remote(host, port, username, password, local_path, remote_path,
     :raise: Whatever remote_scp() raises
     """
     if limit:
-        limit = "-l %s" % (limit)
+        limit = f"-l {limit}"
 
     if host and host.lower().startswith("fe80"):
         if not interface:
             raise SCPError("When using ipv6 linklocal address must assign",
                            "the interface the neighbour attache")
-        host = "%s%%%s" % (host, interface)
+        host = f"{host}%{interface}"
 
     command = "scp"
     if directory:
-        command = "%s -r" % command
+        command = f"{command} -r"
     command += (r" -v -o UserKnownHostsFile=/dev/null "
                 r"-o StrictHostKeyChecking=no "
-                r"-o PreferredAuthentications=password %s "
-                r"-P %s %s %s@\[%s\]:%s" %
-                (limit, port, quote_path(local_path), username, host,
-                 pipes.quote(remote_path)))
+                fr"-o PreferredAuthentications=password {limit} "
+                fr"-P {port} {quote_path(local_path)} {username}@\[{host}\]:"
+                fr"{pipes.quote(remote_path)}")
     password_list = []
     password_list.append(password)
     return remote_scp(command, password_list,
@@ -629,22 +635,21 @@ def scp_from_remote(host, port, username, password, remote_path, local_path,
     :raise: Whatever remote_scp() raises
     """
     if limit:
-        limit = "-l %s" % (limit)
+        limit = f"-l {limit}"
     if host and host.lower().startswith("fe80"):
         if not interface:
             raise SCPError("When using ipv6 linklocal address must assign, ",
                            "the interface the neighbour attache")
-        host = "%s%%%s" % (host, interface)
+        host = f"{host}%{interface}"
 
     command = "scp"
     if directory:
-        command = "%s -r" % command
+        command = f"{command} -r"
     command += (r" -v -o UserKnownHostsFile=/dev/null "
                 r"-o StrictHostKeyChecking=no "
-                r"-o PreferredAuthentications=password %s "
-                r"-P %s %s@\[%s\]:%s %s" %
-                (limit, port, username, host, quote_path(remote_path),
-                 pipes.quote(local_path)))
+                fr"-o PreferredAuthentications=password {limit} "
+                fr"-P {port} {username}@\[{host}\]:{quote_path(remote_path)} "
+                fr"{pipes.quote(local_path)}")
     password_list = []
     password_list.append(password)
     remote_scp(command, password_list,
@@ -675,27 +680,26 @@ def scp_between_remotes(src, dst, port, s_passwd, d_passwd, s_name, d_name,
     :return: True on success and False on failure.
     """
     if limit:
-        limit = "-l %s" % (limit)
+        limit = f"-l {limit}"
     if src and src.lower().startswith("fe80"):
         if not src_inter:
             raise SCPError("When using ipv6 linklocal address must assign ",
                            "the interface the neighbour attache")
-        src = "%s%%%s" % (src, src_inter)
+        src = f"{src}%{src_inter}"
     if dst and dst.lower().startswith("fe80"):
         if not dst_inter:
             raise SCPError("When using ipv6 linklocal address must assign ",
                            "the interface the neighbour attache")
-        dst = "%s%%%s" % (dst, dst_inter)
+        dst = f"{dst}%{dst_inter}"
 
     command = "scp"
     if directory:
-        command = "%s -r" % command
+        command = f"{command} -r"
     command += (r" -v -o UserKnownHostsFile=/dev/null "
                 r"-o StrictHostKeyChecking=no "
-                r"-o PreferredAuthentications=password %s -P %s"
-                r" %s@\[%s\]:%s %s@\[%s\]:%s" %
-                (limit, port, s_name, src, quote_path(s_path), d_name, dst,
-                 pipes.quote(d_path)))
+                fr"-o PreferredAuthentications=password {limit} -P {port}"
+                fr" {s_name}@\[{src}\]:{quote_path(s_path)} {d_name}@\[{dst}\]"
+                fr":{pipes.quote(d_path)}")
     password_list = []
     password_list.append(s_passwd)
     password_list.append(d_passwd)
@@ -747,40 +751,38 @@ def nc_copy_between_remotes(src, dst, s_port, s_passwd, d_passwd,
                                  c_prompt)
 
     try:
-        s_session.cmd("iptables -I INPUT -p %s -j ACCEPT" % d_protocol)
-        d_session.cmd("iptables -I OUTPUT -p %s -j ACCEPT" % d_protocol)
-    except Exception:   # pylint: disable=W0703
+        s_session.cmd(f"iptables -I INPUT -p {d_protocol} -j ACCEPT")
+        d_session.cmd(f"iptables -I OUTPUT -p {d_protocol} -j ACCEPT")
+    except Exception:  # pylint: disable=W0703
         pass
 
-    logging.info("Transfer data using netcat from %s to %s", src, dst)
-    cmd = "nc -w %s" % timeout
+    LOG.info("Transfer data using netcat from %s to %s", src, dst)
+    cmd = f"nc -w {timeout}"
     if d_protocol == "udp":
         cmd += " -u"
-    receive_cmd = ("echo %s | %s -l %s > %s" %
-                   (check_string, cmd, d_port, d_path))
+    receive_cmd = (f"echo {check_string} | {cmd} -l {d_port} > {d_path}")
     d_session.sendline(receive_cmd)
-    send_cmd = "%s %s %s < %s" % (cmd, dst, d_port, s_path)
+    send_cmd = f"{cmd} {dst} {d_port} < {s_path}"
     status, output = s_session.cmd_status_output(
         send_cmd, timeout=file_transfer_timeout)
     if status:
-        err = "Fail to transfer file between %s -> %s." % (src, dst)
+        err = f"Fail to transfer file between {src} -> {dst}."
         if check_string not in output:
             err += ("src did not receive check "
-                    "string %s sent by dst." % check_string)
-        err += "send nc command %s, output %s" % (send_cmd, output)
-        err += "Receive nc command %s." % receive_cmd
+                    f"string {check_string} sent by dst.")
+        err += f"send nc command {send_cmd}, output {output}"
+        err += f"Receive nc command {receive_cmd}."
         raise NetcatTransferFailedError(status, err)
 
     if check_sum:
-        logging.info("md5sum cmd = md5sum %s", s_path)
-        output = s_session.cmd("md5sum %s" % s_path)
+        LOG.info("md5sum cmd = md5sum %s", s_path)
+        output = s_session.cmd(f"md5sum {s_path}")
         src_md5 = output.split()[0]
-        dst_md5 = d_session.cmd("md5sum %s" % d_path).split()[0]
+        dst_md5 = d_session.cmd(f"md5sum {d_path}").split()[0]
         if src_md5.strip() != dst_md5.strip():
             err_msg = ("Files md5sum mismatch, "
-                       "file %s md5sum is '%s', "
-                       "but the file %s md5sum is %s" %
-                       (s_path, src_md5, d_path, dst_md5))
+                       f"file {s_path} md5sum is '{src_md5}', "
+                       f"but the file {d_path} md5sum is {dst_md5}")
             raise NetcatTransferIntegrityError(err_msg)
     return True
 
@@ -812,25 +814,25 @@ def udp_copy_between_remotes(src, dst, s_port, s_passwd, d_passwd,
         info = session.cmd_output(cmd, timeout=360).strip()
         drive_path = re.search(r'(\w):\s+(\S+)', info, re.M)
         if not drive_path:
-            raise UDPError("Not found file %s.%s in your guest"
-                           % (filename, extension))
+            raise UDPError(f"Not found file {filename}.{extension} "
+                           "in your guest")
         return ":".join(drive_path.groups())
 
     def get_file_md5(session, file_path):
         """Get files md5sums."""
         if c_type == "ssh":
-            md5_cmd = "md5sum %s" % file_path
-            md5_reg = r"(\w+)\s+%s.*" % file_path
+            md5_cmd = f"md5sum {file_path}"
+            md5_reg = fr"(\w+)\s+{file_path}.*"
         else:
             drive_path = get_abs_path(session, "md5sums", "exe")
             filename = file_path.split("\\")[-1]
-            md5_reg = r"%s\s+(\w+)" % filename
-            md5_cmd = '%smd5sums.exe %s | find "%s"' % (drive_path, file_path,
-                                                        filename)
+            md5_reg = fr"{filename}\s+(\w+)"
+            md5_cmd = (f'{drive_path}md5sums.exe {file_path} | '
+                       f'find "{filename}"')
         output = session.cmd_output(md5_cmd)
         file_md5 = re.findall(md5_reg, output)
         if not output:
-            raise UDPError("Get file %s md5sum error" % file_path)
+            raise UDPError(f"Get file {file_path} md5sum error")
         return file_md5
 
     def server_alive(session):
@@ -849,11 +851,10 @@ def udp_copy_between_remotes(src, dst, s_port, s_passwd, d_passwd,
     def start_server(session):
         """Start the server."""
         if c_type == "ssh":
-            start_cmd = "sendfile %s &" % d_port
+            start_cmd = f"sendfile {d_port} &"
         else:
             drive_path = get_abs_path(session, "sendfile", "exe")
-            start_cmd = "start /b %ssendfile.exe %s" % (drive_path,
-                                                        d_port)
+            start_cmd = f"start /b {drive_path}sendfile.exe {d_port}"
         session.cmd_output_safe(start_cmd)
         if not server_alive(session):
             raise UDPError("Start udt server failed")
@@ -861,8 +862,7 @@ def udp_copy_between_remotes(src, dst, s_port, s_passwd, d_passwd,
     def start_client(session):
         """Start the client."""
         if c_type == "ssh":
-            client_cmd = "recvfile %s %s %s %s" % (src, d_port,
-                                                   s_path, d_path)
+            client_cmd = f"recvfile {src} {d_port} {s_path} {d_path}"
         else:
             drive_path = get_abs_path(session, "recvfile", "exe")
             client_cmd_tmp = "%srecvfile.exe %s %s %s %s"
@@ -888,9 +888,8 @@ def udp_copy_between_remotes(src, dst, s_port, s_passwd, d_passwd,
         dst_md5 = get_file_md5(d_session, d_path)
         if src_md5 != dst_md5:
             err_msg = ("Files md5sum mismatch, "
-                       "file %s md5sum is '%s', "
-                       "but the file %s md5sum is %s" %
-                       (s_path, src_md5, d_path, dst_md5))
+                       f"file {s_path} md5sum is '{src_md5}', "
+                       f"but the file {d_path} md5sum is {dst_md5}")
             raise UDPError(err_msg)
     finally:
         stop_server(s_session)
@@ -965,26 +964,24 @@ def throughput_transfer(func):
     wrapper function for copy_files_to/copy_files_from function, will
     print throughput if filesize is not none, else will print elapsed time
     """
+
     def transfer(*args, **kwargs):
         """Wrapper transfer function."""
         if "from" in func.__name__:
-            msg = (
-                "Copy file from %s:%s to %s, " %
-                (args[0], args[5], args[6]))
+            msg = f"Copy file from {args[0]}:{args[5]} to {args[6]}, "
         else:
-            msg = (
-                "Copy file from %s to %s:%s, " %
-                (args[5], args[0], args[6]))
+            msg = f"Copy file from {args[5]} to {args[0]}:{args[6]}, "
         start_time = time.time()
         ret = func(*args, **kwargs)
         elapsed_time = time.time() - start_time
         if kwargs.get("fileszie", None) is not None:
             throughput = kwargs["filesize"] / elapsed_time
-            msg += "estimated throughput: %.2f MB/s" % throughput
+            msg += f"estimated throughput: {throughput:.2f} MB/s"
         else:
-            msg += "elapsed time: %s" % elapsed_time
-        logging.info(msg)
+            msg += f"elapsed time: {elapsed_time}"
+        LOG.info(msg)
         return ret
+
     return transfer
 
 
@@ -1005,7 +1002,7 @@ def copy_files_to(address, client, username, password, port, local_path,
     :param limit: Speed limit of file transfer.
     :param log_filename: If specified, log all output to this file (SCP only)
     :param log_function: If specified, log all output using this function
-    :param verbose: If True, log some stats using logging.debug (RSS only)
+    :param verbose: If True, log some stats using LOG.debug (RSS only)
     :param timeout: The time duration (in seconds) to wait for the transfer to
             complete.
     :param interface: The interface the neighbours attach to (only use when
@@ -1021,9 +1018,9 @@ def copy_files_to(address, client, username, password, port, local_path,
     elif client == "rss":
         log_func = None
         if verbose:
-            log_func = logging.debug
+            log_func = LOG.debug
         if interface:
-            address = "%s%%%s" % (address, interface)
+            address = f"{address}%{interface}"
         fdclient = rss_client.FileUploadClient(address, port, log_func)
         fdclient.upload(local_path, remote_path, timeout)
         fdclient.close()
@@ -1048,7 +1045,7 @@ def copy_files_from(address, client, username, password, port, remote_path,
     :param limit: Speed limit of file transfer.
     :param log_filename: If specified, log all output to this file (SCP only)
     :param log_function: If specified, log all output using this function
-    :param verbose: If True, log some stats using ``logging.debug`` (RSS only)
+    :param verbose: If True, log some stats using ``LOG.debug`` (RSS only)
     :param timeout: The time duration (in seconds) to wait for the transfer to
                     complete.
     :param interface: The interface the neighbours attach to (only
@@ -1064,9 +1061,9 @@ def copy_files_from(address, client, username, password, port, remote_path,
     elif client == "rss":
         log_func = None
         if verbose:
-            log_func = logging.debug
+            log_func = LOG.debug
         if interface:
-            address = "%s%%%s" % (address, interface)
+            address = f"{address}%{interface}"
         fdclient = rss_client.FileDownloadClient(address, port, log_func)
         fdclient.download(remote_path, local_path, timeout)
         fdclient.close()
