@@ -34,11 +34,11 @@ def strip_console_codes(output, custom_codes=None):
     old_word = ""
     return_str = ""
     index = 0
-    output = "\x1b[m%s" % output
+    output = f"\x1b[m{output}"
     console_codes = "%[G@8]|\\[[@A-HJ-MPXa-hl-nqrsu\\`]"
     console_codes += "|\\[[\\d;]+[HJKgqnrm]|#8|\\([B0UK]|\\)"
     if custom_codes is not None and custom_codes not in console_codes:
-        console_codes += "|%s" % custom_codes
+        console_codes += f"|{custom_codes}"
     while index < len(output):
         tmp_index = 0
         tmp_word = ""
@@ -55,8 +55,9 @@ def strip_console_codes(output, custom_codes=None):
             special_code = re.findall(console_codes, tmp_word)[0]
         except IndexError as error:
             if index + tmp_index < len(output):
-                raise ValueError("%s is not included in the known console "
-                                 "codes list %s" % (tmp_word, console_codes)) from error
+                raise ValueError(f"{tmp_word} is not included in the known "
+                                 "console codes list "
+                                 f"{console_codes}") from error
             continue
         if special_code == tmp_word:
             continue
