@@ -16,7 +16,7 @@ Naive module that keeps tacks of some opened files and somehow manages them.
 import os
 
 # This variable is used from Avocado-vt
-_open_log_files = {}    # pylint: disable=C0103
+_open_log_files = {}  # pylint: disable=C0103
 
 
 def close_log_file(filename):
@@ -26,9 +26,8 @@ def close_log_file(filename):
     """
 
     remove = []
-    for log_file in _open_log_files:
+    for log_file, log_fd in _open_log_files.items():
         if os.path.basename(log_file) == filename:
-            log_fd = _open_log_files[log_file]
             log_fd.close()
             remove.append(log_file)
     if remove:
